==> haskell-mod-0.2.0.1-68-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-mod.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 mod
version:              0.2.0.1
visibility:           public
id:                   mod-0.2.0.1-JwTbkl4nw8n3jeWhctbK4X
key:                  mod-0.2.0.1-JwTbkl4nw8n3jeWhctbK4X
license:              MIT
copyright:            2017-2022 Andrew Lelechenko
maintainer:           Andrew Lelechenko <andrew.lelechenko@gmail.com>
author:               Andrew Lelechenko <andrew.lelechenko@gmail.com>
homepage:             https://github.com/Bodigrim/mod
synopsis:             Fast type-safe modular arithmetic
description:
    <https://en.wikipedia.org/wiki/Modular_arithmetic Modular arithmetic>,
    promoting moduli to the type level, with an emphasis on performance.
    Originally part of the <https://hackage.haskell.org/package/arithmoi arithmoi> package.

category:             Math, Number Theory
abi:                  84d19f9133641ce9a6b9ad1ea38e113f
exposed:              True
exposed-modules:      Data.Mod Data.Mod.Word
hidden-modules:       Data.Mod.Compat
import-dirs:          /usr/lib/ghc-9.2.8/site-local/mod-0.2.0.1
library-dirs:         /usr/lib/ghc-9.2.8/site-local/mod-0.2.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-mod
hs-libraries:         HSmod-0.2.0.1-JwTbkl4nw8n3jeWhctbK4X
depends:
    base-4.16.4.0 deepseq-1.4.6.1 ghc-bignum-1.2
    primitive-0.7.4.0-EiSZDHCiiZa24trDAETdpw
    semirings-0.6-5TGKcffzLTT7wuioijoGll
    vector-0.13.1.0-1cpgbj3eXUqGZ3uVszXgJ9

haddock-interfaces:   /usr/share/doc/haskell-mod/html/mod.haddock
haddock-html:         /usr/share/doc/haskell-mod/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-mod-0.2.0.1-69-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-mod.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 mod
version:              0.2.0.1
visibility:           public
id:                   mod-0.2.0.1-CvW9OZCuZEl1lxYQIlEiHv
key:                  mod-0.2.0.1-CvW9OZCuZEl1lxYQIlEiHv
license:              MIT
copyright:            2017-2022 Andrew Lelechenko
maintainer:           Andrew Lelechenko <andrew.lelechenko@gmail.com>
author:               Andrew Lelechenko <andrew.lelechenko@gmail.com>
homepage:             https://github.com/Bodigrim/mod
synopsis:             Fast type-safe modular arithmetic
description:
    <https://en.wikipedia.org/wiki/Modular_arithmetic Modular arithmetic>,
    promoting moduli to the type level, with an emphasis on performance.
    Originally part of the <https://hackage.haskell.org/package/arithmoi arithmoi> package.

category:             Math, Number Theory
abi:                  04c228f5fd6987bd6bbec78d3b2cdc84
exposed:              True
exposed-modules:      Data.Mod Data.Mod.Word
hidden-modules:       Data.Mod.Compat
import-dirs:          /usr/lib/ghc-9.2.8/site-local/mod-0.2.0.1
library-dirs:         /usr/lib/ghc-9.2.8/site-local/mod-0.2.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-mod
hs-libraries:         HSmod-0.2.0.1-CvW9OZCuZEl1lxYQIlEiHv
depends:
    base-4.16.4.0 deepseq-1.4.6.1 ghc-bignum-1.2
    primitive-0.7.4.0-LS07XpojUe32dExBFiZWCd
    semirings-0.6-JSA1AgOsk2z1ALmebEKtbK
    vector-0.13.1.0-7kspXIhsfaQEZQW3lsFmcE

haddock-interfaces:   /usr/share/doc/haskell-mod/html/mod.haddock
haddock-html:         /usr/share/doc/haskell-mod/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
